@@ -1,16 +1,15 @@
 
 class Measure(object):
 
-    def __init__(self, label):
+    def __init__(self, label, type='float'): #TODO support type='integer'
         self.label = label
         self._db = None
-        self._spc = None
+
+    def set_db(self, db):
+        self._db = db
+
 
 class Sum(Measure):
 
     def increment(self, old_value, new_value):
         return old_value + new_value
-
-    def fetch(self, **point):
-        key = self._spc.key(point)
-        return self._db.get(key)[self._name]
